Crate common[][src]

This module contains all the routines necessary to calculate the correction factors needed to calibrate a pH meter.

For the caliph calibration binary, the two imports needed in its main function are:

use common::args::CalibArgs;
use common::routines::ph_calibration;

While for conph the pH converter, the two imports needed in it’s main function are:

use common::args::CalibArgs;
use common::routines::ph_convert;

Modules

This contains two submodules for parsing command line inputs using clap for both caliph, and conph

Provides methods to performs linear fit of two input arrays, x and y

Routines Module

Stats Module