pub struct EncoderBuilder { /* private fields */ }Expand description
Chainable builder for Encoder. Defaults match Encoder::new.
Implementations
Sourceimpl EncoderBuilder
impl EncoderBuilder
Sourcepub fn protocol_version(self, v: u8) -> Self
pub fn protocol_version(self, v: u8) -> Self
Set the protocol version byte written at offset 1 of each segment header.
Sourcepub fn profile_version(self, v: u16) -> Self
pub fn profile_version(self, v: u16) -> Self
Set the profile version word written at offsets 2..4 of each segment header.