pub struct UnpackedComponent {
pub target_name: &'static str,
pub raw: u64,
pub bits: u8,
pub scale: Option<f64>,
pub offset: Option<f64>,
pub units: Option<&'static str>,
pub accumulate: bool,
}Expand description
Result of unpacking one component.
Fields
target_name: &'static strComponent’s name from Profile.xlsx — points at another field on the same message that the value should be stored under.
raw: u64Raw integer extracted from the bit stream. Apply scale/offset downstream if needed.
bits: u8scale: Option<f64>offset: Option<f64>units: Option<&'static str>accumulate: boolTrait Implementations
Sourceimpl Clone for UnpackedComponent
impl Clone for UnpackedComponent
Sourcefn clone(&self) -> UnpackedComponent
fn clone(&self) -> UnpackedComponent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnpackedComponent
impl Debug for UnpackedComponent
Sourceimpl PartialEq for UnpackedComponent
impl PartialEq for UnpackedComponent
Sourcefn eq(&self, other: &UnpackedComponent) -> bool
fn eq(&self, other: &UnpackedComponent) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UnpackedComponent