select

Function select 

pub fn select<'a>(
    parent_field: &'a FieldInfo,
    parent_mesg: &MesgInfo,
    raw_message: &RawMessage<'_>,
) -> Option<&'a SubField>
Inspect a parent field’s sub_fields and return the first one whose condition matches the parent message. Returns None when no SubField applies (in which case the parent field keeps its default semantics).